@@ -3,8 +3,8 @@ import zipfile
 import os
 import codecs
 import json
-#from XmindToTestlink import read_xml
-import read_xml
+from XmindToTestlink import read_xml
+#import read_xml
 
 class DictToJson(object):
     def __init__(self):
