@@ -7,6 +7,7 @@ from XmindToTestlink import read_xml
 
 class DictToXml(object):
     def __init__(self):
+        self.update = 0
         self.case_tag = {
                 "ts":"testsuite",
                 "tc":"testcase",
@@ -122,6 +123,17 @@ class DictToXml(object):
                 path = pre_path + '/' + in_dict['title']
                 tmp_path = path
                 reqs_id = self.get_md5(path)
+            elif self.update:
+                path = pre_path + '/' + in_dict['title']
+                tmp_path = path
+                if path in self.id_dict:
+                    reqs_id = self.id_dict[path]
+                else:
+                    pre_suite = "/".join(path.split("/")[:-1])
+                    if pre_suite in self.suite_id:
+                        id_msg = self.suite_id[pre_suite].split(".")
+                        reqs_id = ".".join(id_msg[:-1]) + "." + str(int(id_msg[-1]) + 1)
+                        self.suite_id[path] = reqs_id + ".0"
             else:
                 reqs_id = root_id
             ts = ET.SubElement(node, self.req_tag['rqs'], attrib = {"title" : in_dict['title'], "doc_id" :reqs_id})
@@ -134,6 +146,18 @@ class DictToXml(object):
                 if auto_id:
                     path = tmp_path + '/' + case['title']
                     req_id = self.get_md5(path)
+                elif self.update:
+                    path = tmp_path + '/' + case['title']
+                    if path in self.id_dict:
+                        req_id = self.id_dict[path]
+                    else:
+                        pre_suite = "/".join(path.split("/")[:-1])
+                        if pre_suite in self.suite_id:
+                            id_msg = self.suite_id[pre_suite].split(".")
+                            req_id = ".".join(id_msg[:-1]) + "." + str(int(id_msg[-1]) + 1)
+                            self.suite_id[pre_suite] = req_id
+                        else:
+                            pass
                 else:
                     req_id = reqs_id + "." +  str(id_count)
                     id_count += 1
@@ -160,14 +184,51 @@ class DictToXml(object):
                 if auto_id:
                     path = pre_path + '/' + in_dict['title']
                     self.get_req_xml(suite, ts, auto_id, root_id, path)
+                elif self.update:
+                    path = pre_path + '/' + in_dict['title']
+                    if path in self.id_dict:
+                        root_id = self.id_dict[path]
+                    else:
+                        pre_suite = "/".join(path.split("/")[:-1])
+                        if pre_suite in self.suite_id:
+                            id_msg = self.suite_id[pre_suite].split(".")
+                            req_id = ".".join(id_msg[:-1]) + "." + str(int(id_msg[-1]) + 1)
+                            self.suite_id[path] = req_id + ".1"
+                    self.get_req_xml(suite, ts, auto_id, root_id, path)
                 else:
                     root_id = reqs_id + "." + str(id_count)
                     id_count += 1
                     self.get_req_xml(suite, ts, auto_id, root_id)
 
+    def get_suite_id(self, id_dict):
+        suite_id = {}
+        for path, pid in id_dict.items():
+            if path in self.only_reqs_id_dict:
+                if path not in suite_id:
+                    suite_id[path] = pid + ".0"
+                else:
+                    old_count = int(suite_id[path].split(".")[-1])
+                    now_count = int(pid.split(".")[-1])
+                    if old_count < now_count:
+                        suite_id[path] = pid
+            msg = path.split('/')
+            pre_path = "/".join(msg[:-1])
+            if pre_path in id_dict:
+                if pre_path not in suite_id:
+                    suite_id[pre_path] = pid
+                else:
+                    old_count = int(suite_id[pre_path].split(".")[-1])
+                    now_count = int(pid.split(".")[-1])
+                    if old_count < now_count:
+                        suite_id[pre_path] = pid
+        return suite_id
 
-    def read_req_id_dict(self, req_xml_path):
+    def read_req_id_dict(self, req_xml_path, update=''):
         self.id_dict = read_xml.read_req_id_xml(req_xml_path)
+        if update == 'update':
+            self.only_reqs_id_dict = read_xml.read_only_reqs_id_xml(req_xml_path)
+            self.suite_id = self.get_suite_id(self.id_dict)
+            self.update = 1
         #print(self.id_dict)
     
     def get_case_xml(self, in_dict, node = '', api = False, argv = '',\
