@@ -4,12 +4,12 @@ import os
 import codecs
 import json
 import argparse
-from XmindToTestlink import markdown_to_dict
-from XmindToTestlink import dict_to_json
-from XmindToTestlink import zip_need
-#import markdown_to_dict
-#import dict_to_json
-#import zip_need
+#from XmindToTestlink import markdown_to_dict
+#from XmindToTestlink import dict_to_json
+#from XmindToTestlink import zip_need
+import markdown_to_dict
+import dict_to_json
+import zip_need
 
 
 def md_to_xmind():
